:
# cronset.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.1.4 Sep 12 09:21:02 PDT 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module donated by Mitko Stoyanov, August 1999
 
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/cron /etc/cron.d/logchecker'
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`

export CRONLOGDIR="/var/adm/cron"
export CRONDFILE="/etc/security/audit/config"
export EVNTFILE="/etc/security/audit/events"

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh
 
Intro() {
cat << EOF_INTRO

${MYNAME} : This script checks/puts cron settings into /etc/security/audit,
and /etc/security/events, It also changes the permissions of /var/adm/cron
so that the users cannot peek into the contents of the cron log files. 

EOF_INTRO
}

Check() {

#Check whether cron logging is enabled in /etc/security/audit/config
# Verify that there are specific events to log as well, else settings
# in /etc/security/audit/config are meaningless. 
# 

  if [ -r "$CRONDFILE" ]; then
   if [ -n "`grep -v '\#' ${CRONDFILE} | fgrep -i '	cron'`" ]; then
      echo "   CRONLOG entry found - PASSES CHECK "
   else
      echo "  CRONLOG entry not found or misconfigured - FAILS CHECK" 
   fi
  fi
#
# Check wether we have any events defined to produce output
# with any value at all...

  if [ -r "$EVNTFILE" ]; then
   if [ -n "`fgrep '	CRON_Finish' ${EVNTFILE}`" ]; then
      echo "   EVENT entry found - PASSES CHECK "
   else
      echo "  EVENT entry not found or misconfigured - FAILS CHECK" 
   fi
 fi


#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       echo "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       echo "   $CRONLOGDIR permissions - FAILS CHECK " 
      fi

}


Fix() {

  if [ -r "$CRONDFILE" ]; then
   if [ -n "`grep -v '\#' ${CRONDFILE} | fgrep -i '	cron'`" ]; then
      echo "   CRONLOG entry found - PASSES CHECK "
   else
      echo "  CRONLOG entry not found or misconfigured - FAILS CHECK" 

	#
	# Note that this has to be installed into the classes
	# category in /etc/security/audit/config...
	#
      	echo "  Fixing $CRONDFILE now...." 
	ed - ${CRONDFILE} <<- EOEF
	/^classes
	r ./lib/cron-config
	w!
	wq!
	EOEF

   fi
  fi

#
# Check wether we have any events defined to produce output
# with any value at all...

  if [ -r "$EVNTFILE" ]; then
   if [ -n "`fgrep '	CRON_Finish' ${EVNTFILE}`" ]; then
      echo "   EVENT entry found - PASSES CHECK "
   else
      echo "  EVENT entry not found or misconfigured - FAILS CHECK" 
	#
	# Fix events file here...
      	echo "  Fixing $EVNTFILE now...." 
	#
	# This can fall anywhere in the /etc/security/audit/events file
	# as it is a write log rule only
	#
	cat ../lib/cron-events >>${EVNTFILE}
	# cat ../lib/cron-events >>/tmp/etc/security/audit/events
   fi
 fi

#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       echo "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       echo "   $CRONLOGDIR permissions - FAILS CHECK " 
       echo "   Fixing the $CRONLOGDIR permissions ... " 
       if [ -d "$CRONLOGDIR" ]; then :
       else
         mkdir -p /var/adm/cron
       fi
         chmod  700 /var/adm/cron && chown root /var/adm/cron \
         && chgrp sys /var/adm/cron
   fi

}

 
action=$1
case $action in
 -[Ff]*)
Fix
Check
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        echo " "
;;
esac
