:
# defuserparams.sh
# version 1.0 Oct 15 2003 - AIX,v5.2 specific changes
#
# 06/22/2001 - Modifications contributed by Kyle Haugsness
#               added PATH, SUPATH, SLEEPTIME, RETRIES,
#               and SYSLOG_FAILED_LOGINS variable support.
#               Also set a tighter UMASK.
# version 4.0 beta1
# version 4.0 BETA 2 Nov 2, 2001 incorporated patch from Thomas Bennett
#
# version 4.1 Oct 15 2003 - AIX,v5.2 specific changes , M. Archibald

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
# 2002, 2003
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module origionally by Mitko Stoyanov, August 1999 for Solaris
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M%S`
RUNDATE=`/usr/bin/date +%Y%m%d%H%M%S`
# echo "Rundate = $RUNDATE, Date = $DATE"
# exit 0
LOGINDEF='/etc/security/user'
TDEFLIB='./lib/user-defparams'
SAVEFILES='/etc/security/user'

#
# Default parameters we/you are interested in. Must have a matching default in 
# ${TITANHOME}/lib/user-defparams to be able to compare/set correctly even if
# a null value in the lib file
DEFPARAMS="admin login su daemon rlogin sugroups ttys auth1 auth2 tpath umask SYSTEM pwdwarntime account_locked loginretries histexpire histsize minage maxage maxexpired minalpha minother minlen mindiff maxrepeats"



. misc_functions.sh

OS=`uname -r`

# BEGIN CONFIGURABLE STUFF for AIX User defaults in /etc/security/user
# this section is:
# (C) COPYRIGHT International Business Machines Corp. 1985-1998,2001-2003
# reference taken from /etc/security/user  for AIX,v5.2 as of Oct. 2003
#
# For the 'default' user creation class the following may be set...
# we only deal with the obvious for passwird, timeouts etc...
# You are free to tweak this to your own desires...
#
# default:
# admin = false   (Should default mkuser create admin true/false)
# login = true	  (Can the user login post-creation true/false)
# su = true	  (Can other users su to this account true/false)
# daemon = true   (Can the user execute commands as services true/false)
# rlogin = true	  (Can the user use rlogin/telnet true/false)
# sugroups = ALL  (Groups can/cannot(!) su to this account, group, group1..)
# admgroups =	  (Set admin group privilege, if admin, <group, group1,..)
# ttys = ALL	  (Ttys can/cannot(!) access this account, tty, tty1, ALL..)
# auth1 = SYSTEM  (Primary authentication, SYSTEM, NONE, token;<name> )
# auth2 = NONE	  (Not required... See auth1...)
# tpath = nosak   (Trusted path, (Requires Secure Attention Key sak_enabled))
# umask = 022	  (Default umask for the account, 022, 042, 020, 021...)
# expires = 0     (Expiration for account, MMDDHHMMMYY, 0 = never)
# SYSTEM = "compat" (V4 authentication, files (local), DCE, compat(local+NIS))
# logintimes =	  (Login time, [!][MMdd[-MMdd]]:hhmm-hhmm, [!]w[-w][:hhmm-hhmm])
# pwdchecks=      (Password syntax restriction methods via external code, NULL) 
# pwdwarntime = 0 (Number of days to forced password changed or lock out)
# account_locked = false (Is account locked post mkuser, true/false)
# loginretries = 0 (Number invalid attempts before lockout, 0=unlimit,1-999)
# histexpire = 0   (Weeks before re-use of password, 0=unlimit,1-260)
# histsize = 0	   (Number of unique password before re-use, 0=unlimit, 1-50) 
# minage = 0	(Min. weeks between password changes, 0=unlimit, 1-52)
# maxage = 0	(Max. weeks password is valid befor echange required, 0=unlimt, 1-52)
# maxexpired = -1	(Max. weeks after expire before change forced, -1=off, 1-52)
# minalpha = 0	(Min. number alpha characters in password, 0=unlimit,1-8)
# minother = 0  (Min. number non-alpha characters in password, 0=unlimit,1-8)
# minlen = 0 	(Min. password length required, 0=unlimit,1-8)
# mindiff = 0	(Min. diff against previous password, 0=unlimit,1-8)

# END CONFIGURABLE STUFF

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {
cat << EOF_INTRO
$MYNAME : This script checks/updates the /etc/security/user file 'default' class
with a set of reasonable, at lease we think so, default account configuration values.
We use /usr/bin/lssec to check values against defaults, note that the output from lssec
drops any leading "0" characters, affects umask and other items with a "0" leading
chartacter as well as "0"=unlimited default settings. In this case we simply set to the
recommended in ${TITANHOME}/lib/user-defparams. Those that Titan recommends settings for,
from ${TITANHOME}/lib/user-defparams, and will update, are:

        admin = false
        login = true
        su = true
        daemon = true
        rlogin = true
        sugroups = ALL
        ttys = ALL
        auth1 = SYSTEM
        auth2 = NONE
        tpath = nosak
        umask = 022
        SYSTEM = "compat"
        pwdwarntime = 15
        account_locked = false
        loginretries = 5
        histexpire = 5
        histsize = 5
        minage = 3
        maxage = 8
        maxexpired = -1
        minalpha = 3
        minother = 3
        minlen = 8
        mindiff = 4
        maxrepeats = 8

EOF_INTRO
}


Check() {

#There should be only ONE uncommented <PARAM>= line for each parameters
#and it should be exactly the same as we want it to be. 

   if [ -r "$LOGINDEF" ]; then 
	if [ -r "$TDEFLIB" ]; then

for DEFUSERPARAM in ${DEFPARAMS}; do

# Debug
#
# /usr/bin/lssec -f ${LOGINDEF} -s default -a ${DEFUSERPARAM}
# /usr/bin/grep "${DEFUSERPARAM}=" ./lib/user-defparams
# done
# exit 0

#
# Runtime
#
DDEF="`/usr/bin/lssec -f ${LOGINDEF} -s default -a ${DEFUSERPARAM} | awk -F"=" '{printf("%s",$NF);}' | tr -d ' '`"
TDEF="`/usr/bin/grep "^${DEFUSERPARAM}=" ${TDEFLIB} | awk -F"=" '{printf("%s",$NF);}' | tr -d ' '`"
   
	# echo "Matching ${DDEF} to ${TDEF}"
	if [ "${DDEF}" = "${TDEF}" ]; then
            echo "${DDEF}=${TDEF} - PASSES"
	else
            echo "${DDEF}!=${TDEF} - FAILS"
	fi
     done
    exit 0
   else
    echo "No ${TDEFLIB} found... error"
 fi
    echo "No ${LOGINDEF} found... error"
fi

}


Fix() {

#There should be only ONE uncommented <PARAM>= line for each parameters
#and it should be exactly the same as we want it to be. 

   if [ -r "$LOGINDEF" ]; then 
	/bin/cp ${LOGINDEF} ${LOGINDEF}-preTitan-${RUNDATE}
	if [ -r "$TDEFLIB" ]; then

for DEFUSERPARAM in ${DEFPARAMS}; do

# Debug
#
# /usr/bin/lssec -f ${LOGINDEF} -s default -a ${DEFUSERPARAM}
# /usr/bin/grep "^${DEFUSERPARAM}=" ./lib/user-defparams
# done
# exit 0

#
# Runtime
#
DDEF=`/usr/bin/lssec -f ${LOGINDEF} -s default -a ${DEFUSERPARAM} | awk -F"=" '{printf("%s ",$NF);}'| tr -d ' '`
TDEF=`/usr/bin/grep "^${DEFUSERPARAM}=" ${TDEFLIB} | awk -F"=" '{printf("%s ",$NF);}'| tr -d ' '`
   
	# echo "Matching ${DDEF} to ${TDEF}"
	if [ "${DDEF}" = "${TDEF}" ]; then
            echo "${DDEF} = ${TDEF} - PASSES"
	else
            echo "${DDEF}!= ${TDEF} - FIXING"
    /usr/bin/chsec -f ${LOGINDEF} -s default -a "${DEFUSERPARAM}=${TDEF}"
	fi
     done
#    exit 0
   else
    echo "No ${TDEFLIB} found... exit with error"
    exit 1
 fi
    echo "No ${LOGINDEF} found... exit with error"
fi

#
# Run Check last to show that we did something intelligent...
#
# Check

}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        echo " "
;;
esac

