:
# disable-ping-echo.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.1 Thu Nov  5 13:06:19 PST 1998 bpowell: new check to see
# if you already had a line, so we don't keep adding one in if you
# run -F multiple times
# version 3.0.3  Fri Jan  8 18:42:25 PST 1999 bpowell: for i loop in Fix()
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0.10 Fri Apr  6 07:47:10 PDT 2001
# version 4.1 Fri Oct 25 04:47:10 PDT 2003 - M. Archibald AIX,5.2 stuff

#
# Things in general to fix in the network stack etc.... from vendor
# recommendations are:

# Decrease the ARP cache cleanup interval. AIX no -o arpt_killc=20
# Disable ICMP broadcast echo activity. Otherwise, your system could be used as part of a Smurf attack: AIX no -o directed_broadcast=0
# Disable ICMP routing redirects. Otherwise, your system could have its routing table misadjusted by an attacker. AIX no -o ipignoreredirects=1
# Disable ICMP broadcast probes. Otherwise, an attacker might be able to reverse engineer some details of your network infrastructure. AIX no -o icmpaddressmask=0
# Disable IP source routing. The only use of IP source routing these days is by attackers trying to spoof IP addresses that you would trust as internal hosts. AIX no -o ipsrcroutesend=0
# The following show the vendor recommendations for tuning the TCP queue length and circuit establishment timers, and how to reduce TCP TIME_WAIT to 60 seconds. AIX no -o clean_partial_conns=1
# Increase TCP send and receive window sizes to at least 32 kbytes. But do not increase these above 64 kbytes unless you fully understand and support both RFC 1323 and RFC 2018. AIX no -o tcp_sendspace=32768
# 
# 
umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/bin/date +%m%d%y%H%M%S`
SAVEFILES='/etc/rc.net'
CONFILE='/etc/rc.net'


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi
 

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF
 $MYNAME : This disables ip_respond_to_echo_broadcast so that 
 specific ping crashes don't work. The program modifies /etc/rc.net
 and looks for directed_broadcast=0, if not found, or set we
 add this into /etc/rc.net using:

	/usr/sbin/no -o directed_broadcast=0

EOF

}

Check() {

if [ -f ${CONFILE} ]; then
 grep "directed_broadcast=0" ${CONFILE} >/dev/null 2>&-
   if [ $? -eq 0 ]; then
    t_echo 1 "         Ping echo response denied - PASSES CHECK"
    t_echo 2 " "
   else
    t_echo 0 "         Ping echo response allowed - FAILS CHECK"
    t_echo 0 " "
    exit 1
   fi
 else
   t_echo 2 "	Could not locate ${CONFILE} - CHECK ERROR". 
 fi
}

Fix() {

if [ -f ${CONFILE} ]; then
 /bin/cp ${CONFILE} ${CONFILE}-preTitan-${RUNDATE}
 grep "directed_broadcast=0" ${CONFILE} >/dev/null 2>&-
   if [ $? -eq 0 ]; then
    t_echo 1 "         Ping echo response denied - PASSES CHECK"
    t_echo 2 " "
   else
    t_echo 0 "         Ping echo response allowed - FAILS CHECK"
ed - ${CONFILE} <<- !
/unset RCNETNO
i
# Disable icmp echo response - Titan Security Toolkit http://www.fish.com/titan
/usr/sbin/no -o directed_broadcast=0

.
w
q
!
fi
Check
 else
  t_echo 2 "	Could not locate ${CONFILE} - CHECK ERROR". 
fi

}

action=$1
case ${action} in
	-[Ii])
	Intro
	;;
	-[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
        t_echo 1 "         ERROR:Invalid arg $action"
        t_echo 1 "         ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
esac
