:
#
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.1 Thu Nov  5 12:32:00 PST 1998 bpowell fixed up so that
# accounts less than 100 really get set to noshell 
# version 3.0.2 Tue Dec 15 10:00:15 PST 1998 fixed a bug where blank shells
# now get set almost properly
# version 3.0.3 Mon Jan  4 17:00:30 PST 1999 bpowell/zen fix so that both
# blank shells as well as anything else in the illegal range gets set to noshell 
# version 3.0.6 Thu Feb 25 08:54:54 PST 1999 bpowell make the check and fix
# be consistent by checking/disabling everything including sys
# version 3.2.1 Thu Oct 14 08:43:35 PDT 1999 suggestion by Dieter Gobbers to
# check for noshell in the fix() area and leave it alone if its already set to 
# noshell
# version 3.2.2 bug fix for above

# Modified Oct 2000 to work for Red Hat 6.2
# Erik Ginorio <eginorio@cisco.com>

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`

OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi


#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF
 
 Ensure login shell for "system" accounts are disabled
 these are accounts < 100 > 60000 by default but may
 include others.  A basic listing for SysV Unix is:

 bin, daemon, adm, lp, smtp, sys, uucp, nuucp, listen, nobody, noaccess

 Note: "sys" account might need to be left open since it starts accounting
	on some systems. Titan turns it off by default

 Note2: PLEASE look at $TITANDIR/src1/noshell.c A binary version of noshell is
	MUCH better than this shell version. Replace the /sbin/noshell that this
	script creates with the noshell.c binary you compile if possible.
 
EOF

}

CreateNoShell() {

if [ -f /sbin/noshell ]
    then
                t_echo 2 "        File /sbin/noshell already exists; not changing"
                else
  t_echo 0 "         Creating /sbin/noshell"
  t_echo 2 " "

cat << EOF > /sbin/noshell
:
trap "" 1  2  3  4  5  6 7 8 9 10 11 12 15 19

HOSTNAME=`uname -n`
USER=`id | awk '{print $1}'`
/bin/cat /dev/null |mailx -s "Attempted access by ${USER} on host ${HOSTNAME}" root@${HOSTNAME} &
echo "Sorry"
wait
exit

EOF
		chmod 555 /sbin/noshell
		if [ $? -ne 0 ]
                then
                t_echo 1 " Problems creating /sbin/noshell; exiting "
                exit 1
             fi  
        fi

}

Check() {

#
# Get UID/Uname under UID 100 and over UID 60001
# EXCEPT accounts that may need special shells 
# (like shutdown or halt under linux ?)
PLIST=`awk -F":" '($3 < 100) {print};($3 > 60000) {print}' /etc/passwd |
  egrep -v '(^root\:|^sync\:|^shutdown\:|^halt\:)' |
  awk -F":" '{print $1}'`

PCOUNT=`echo $PLIST | wc -w`
t_echo 2 " Checking $PCOUNT Users.... "
t_echo 2 " Checking that shell set to noshell for: "
t_echo 2 -n " "
t_echo 2 $PLIST

GCOUNT=0
BCOUNT=0

t_echo 2 " Verify shell status.... "
t_echo 2 " "
for USR in $PLIST
 do
  NOSHEL=`grep "^$USR\:" /etc/passwd | grep ":/sbin/noshell$"`
  USHEL=`grep "^$USR\:" /etc/passwd | awk -F":" '{print $7}'`
  if [ -z "$NOSHEL" ]; then
   t_echo 0 "         $USR shell = $USHEL - FAILS CHECK"
   BCOUNT=`expr $BCOUNT + 1`
  else
   t_echo 2 " $USR shell secure = $USHEL - PASSES CHECK"
   GCOUNT=`expr $GCOUNT + 1`
  fi
done

t_echo 2 " "

  if [ $GCOUNT -lt $PCOUNT ]; then
 t_echo 2 " $BCOUNT Users Not Secured Out Of $PCOUNT"
 t_echo 2 " "
  fi

  if [ $GCOUNT -eq $PCOUNT ]; then
 t_echo 2 "         All User Accounts PASS CHECK"
	exit 1
  fi
	

}

Fix() {

t_echo 0 " Setting shell to noshell for: "

# Get UID/Uname under UID 100 and over UID 60001
PLIST=`awk -F":" '($3 < 100) {print};($3 > 60000) {print}' /etc/passwd |\
 egrep -v '(^root\:|^sync\:|^shutdown\:|^halt\:|:/sbin/noshell$)' | 
 awk -F":" '{print $1}'`

t_echo 0 " "
t_echo 0 "$PLIST"
t_echo 0 " "

for USER in $PLIST
 do
 t_echo 0 "        $USER login not disabled. REPAIRING"

ed - /etc/passwd << EOEF
g/^$USER:/s/:[^:]*$/:\/sbin\/noshell/g
.
w
q
EOEF
 t_echo 2 "         $USER shell now =  noshell - PASSES CHECK"
 t_echo 2 "         -----------------------------------------" 
done
 
}

action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	CreateNoShell
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
 t_echo 1 "         ERROR:Invalid arg $action"
 t_echo 1 "         ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 t_echo 1 " "
	;;
	esac
# finis



# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/sbin/noshell /etc/passwd'
