:
#
# version 3.0 Sep 25 11:21:02 PDT 1998

# Modified Oct 2000 to work for Red Hat 6.2
# Erik Ginorio <eginorio@cisco.com>

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`

OS=`uname`
HOST=`uname -n`

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

case $OS in
  *inux)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 60000) {print $1}' /etc/passwd`
  ;;
  5*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 60000) {print $1}' /etc/passwd`
  ;;
  4*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 65000) {print $1}' /etc/passwd`
  ;;
 *)
   t_echo 1 "       No valid OS for local ftpusers"
 exit 1
;;
esac

# testing
#echo $LOCALFTPUSERS

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi


Intro() {

cat << EOF

   This program looks for /etc/ftpusers and if not found creates it.
   If it is found it saves the origional then adds all users with UID
   less than 100 and greater than 60000 and sets the mode on the file.

EOF

}

#
#
# I changed this to reflect default users in the /etc/passwd file on RedHat
#
DEFFTPUSERS="root bin daemon adm lp sync shutdown halt mail news uucp operator games gopher ftp nobody xfs named gdm piranha postgres ovm squid"


FixFtpuser() {

        if [ -f /etc/ftpusers ]
        then
        t_echo 2 " /etc/ftpusers already exists; saving a copy "
        /bin/cp /etc/ftpusers /etc/ftpusers.ORIG.${DATE}
		if [ $? -ne 0 ]
       		then
                 t_echo 1
                 t_echo 1 "       ERROR - Could not rename /etc/ftpusers; exiting"
			exit 1
		fi
	fi

 
# if there is a file /etc/ftpusers append it
 
if [  -f /etc/ftpusers ]
then
	t_echo 2 " Checking and appending names to /etc/ftpusers..."
	t_echo 2 " Checking default ftpusers names..."
	/bin/touch /etc/ftpusers
	for USER in $DEFFTPUSERS
	 do
	   grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>/etc/ftpusers
	   else
              t_echo 2 " $USER in /etc/ftpusers - PASSES CHECK"
	   fi
	 done

	t_echo 2 " Checking your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	   grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>/etc/ftpusers
	   else
              t_echo 2 "        $USER in /etc/ftpusers - PASSES CHECK"
	   fi
	 done
	 if test "X$ftpx" != "X" ; then
	    t_echo 2 " Added users to /etc/ftpusers."
	 fi

fi


# if there isn't a file ftpuser, create it
if [  ! -f /etc/ftpusers ]
then
 t_echo 0 " Creating /etc/ftpusers disallowing ftp to the following users:"
 t_echo 0 $DEFFTPUSERS
 t_echo 0 " "

	/bin/touch /etc/ftpusers
 t_echo 2 " Installing default ftpusers names..."
	for USER in $DEFFTPUSERS
	 do
 echo $USER >>/etc/ftpusers
	done

 t_echo 2 " Installing your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	if [ $? -ne 0 ]; then
 echo $USER >>/etc/ftpusers
	else
 t_echo 2 "       $USER in /etc/ftpusers - PASSES CHECK"
	fi
	done

fi

# chmod it when done
/bin/chmod 644 /etc/ftpusers

} # End FixFtpuser


CheckFtpuser() {

t_echo 2 " Checking /etc/ftpusers file for default matches...."
   for USER in $DEFFTPUSERS
    do
    grep "^$USER" /etc/ftpusers >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in /etc/ftpusers - FAILS CHECK" 
     else
     t_echo 2 "        $USER in /etc/ftpusers - PASSES CHECK"
     fi
    done

t_echo 2 " "
t_echo 2 " Checking /etc/ftpusers file for local matches...."
   for USER in $LOCALFTPUSERS
    do
    grep "^$USER" /etc/ftpusers >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in /etc/ftpusers - FAILS CHECK"
     else
     t_echo 2 "        $USER in /etc/ftpusers - PASSES CHECK"
     fi
    done

}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        FixFtpuser
        ;;
        -[Vv]*)
	if [ -f /etc/ftpusers ]; then
           t_echo 2 "          The /etc/ftpusers file exists..."
           t_echo 2 "          Your default ftpusers names: "
           t_echo 2 " "
           t_echo 2 $DEFFTPUSERS
           t_echo 2 " "
           t_echo 2 "       Your local ftpusers names: "
           t_echo 2 " "
           t_echo 2 $LOCALFTPUSERS
           t_echo 2 " "
           CheckFtpuser
	else
           t_echo 0 "       No /etc/ftpusers file in place..."
           t_echo 2 "       Should contain at least: "
           t_echo 2 " "
 	for USER in $DEFFTPUSERS
    	   do
              t_echo 2 " $USER"
 	done
        t_echo 2 " "
        t_echo 0 "       Please Run with '-F/f' to Fix - FAILS CHECK"
 	exit 1
	fi
        ;;
        *)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac



# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/etc/ftpusers'
