#!/bin/sh
# :
#
# version 3.0 Sep 25 11:21:02 PDT 1998

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module by Mitko Stoyanov, August 1999
 
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`


USERADD_DEFCMD="/usr/sbin/useradd -D "
U_DEFDIR="/usr/users"
U_DEFSH="/usr/bin/ksh"
U_DEFGRP="users"
U_DEFGID="15"
U_DEFINACTIVE="30"


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh


if [ -x /usr/bin/nawk ];then
AWK=/usr/bin/nawk
elif [ -x /usr/bin/awk ];then
AWK=/usr/bin/awk
fi

U_DEFSH="/usr/bin/ksh"

if [ -x "$U_DEFSH" ];then :
else
 echo "The default shell $U_DEFSH does not exists or is not executable - FAILS CHECK" 
fi

if [ -d "$U_DEFDIR" ];then :
else
 echo "The default base dir $U_DEFDIR does not exists - FAILS CHECK" 
fi
 
Intro() {
cat << EOF_INTRO
This script checks/puts the default settings for /usr/sbin/useradd.
It creates initial /etc/login.defs if it does not exists via
"useradd -D", and backups the settings in /etc/login.defs. 
Of interest is mostly the inactivity period (7th field in /etc/shadow)
for the user.
Note that other programs for user creation such as admintool ignore
these defaults.
EOF_INTRO
}

ChkDefGrp () {

# Check the users default group. There should be only one such
# group, any duplicates of the group name or GID will result in
# failure.Take no chances, I've seen quite a few /etc/group files
# with all sorts of dups (MS 03/09/1999).

$AWK -v defgrp="$U_DEFGRP" -v defgid="$U_DEFGID" -F":" '
     BEGIN {
     usrgrp = 0;
     grpgid = 0;
     defgroupok = 0;
     while (getline <  "/etc/group" > 0) {
     if( $1 == defgrp ) {
       usrgrp++;
       if ($3 == 15 ) {
        grpgid++;
        defgroupok++; 
             }
          }
       }
      }
END {
    #printf("%d:%d:%d\n",defgroupok,usrgrp,grpgid );
    if ( defgroupok == 1 && usrgrp == 1 && grpgid == 1) {exit 0;}
    else {exit 1;}
 }' < /dev/null
  
 retvalue=$?
 return $retvalue

}

Check() {


   if ChkDefGrp ;then
      t_echo 2 "  default user group for useradd - PASSES CHECK"
   else
      t_echo 0 "  default user group for useradd - FAILS CHECK"
   fi

#Check now the useradd defaults

   $USERADD_DEFCMD  | tr -d '\012' | $AWK -v defgrp="$U_DEFGRP" \
   -v defgid="$U_DEFGID" -v defdir="$U_DEFDIR" \
   -v definact="$U_DEFINACTIVE" -v defsh="$U_DEFSH" '{
                workline=$0;
                split(workline,d_params);
                for (i in d_params ) {
                if (d_params[i] ~ /basedir=/) {
                offset=index(d_params[i],"=");
                d_basedir=substr(d_params[i],offset+1);
                        }
                else if (d_params[i] ~ /shell=/) {
                offset=index(d_params[i],"=");
                d_shell=substr(d_params[i],offset+1);
                        }
                else if (d_params[i] ~ /inactive=/) {
                offset=index(d_params[i],"=");
                d_inactive=substr(d_params[i],offset+1);
                        }
                else if (d_params[i] ~ /group=/) {
                offset=index(d_params[i],"=");
                offset=index(d_params[i],"=");
                offset2=index(d_params[i],",");
                d_group=substr(d_params[i],offset+1,offset2 -(1 + offset));
                        }
                   }
                }
                END {
                if(d_basedir == defdir && d_shell == defsh &&  
                d_inactive == definact && d_group =  defgrp ) { exit 0; }
                else { exit 1;}
                }' 
  if [ $? -ne 0 ];then
    t_echo 0 "  useradd defaults - FAILS CHECK "
  else
    t_echo 2 "  useradd defaults - PASSES CHECK"
  fi

}


Fix() {

  if ChkDefGrp ;then
    t_echo 2 "  default user group for useradd - PASSES CHECK"
  else
    t_echo 0 "  default user group for useradd - FAILS CHECK"
    t_echo 0 "  Fixing the default user group for useradd now..."
    if /usr/sbin/groupadd -g $U_DEFGID $U_DEFGRP > /dev/null 2>&1 ;then
      t_echo 0 "  default user group for useradd - FIXED"
    else
      t_echo 0 "  default user group for useradd - ERROR FIX FAILED"
    fi
  fi

 if ChkDefGrp ;then 
  if $USERADD_DEFCMD >/dev/null 2>&1 && cp -p /etc/login.defs \
   /etc/login.defs.${RUNDATE} ;then
   /usr/bin/cat > /etc/login.defs <<- __INPUT__
	# defaults for useradd put by $MYNAME at $RUNDATE
	#
	defgroup=$U_DEFGID
	defgname=$U_DEFGRP
	defparent=$U_DEFDIR
	defskel=/etc/skel
	defshell=$U_DEFSH
	definact=$U_DEFINACTIVE
	defexpire=  
	__INPUT__
    t_echo 0 "  useradd defaults - FIXED"
  else
    t_echo 2 "  useradd defaults - FIX FAILED"
  fi
 else
  t_echo 2 "  useradd defaults ChkDefGrp - FIX FAILED"
 fi

}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        echo " "
;;
esac



# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/etc/login.defs'
