:
# tcp-sequence.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0 beta1

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 
#
# KWH modified - this module shouldn't backup the config file until it has
# determined that it needs to change the file.

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/inetinit'

. misc_functions.sh

case "`uname -r`" in
5.[678]*) ;;
*)
        t_echo 1 "$MYNAME ERROR - This feature is Only supported on Solaris 2.6 and newer "
        exit 1;;
esac


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {

cat << EOF
 
 $MYNAME - Changes the TCP initial sequence number generation parameters
 to use RFC 1948 sequence number generation, unique-per-connection-ID

EOF

}

Fix() {

if [ -f /etc/default/inetinit ]; then
  TCP_VAL=`grep -i "^[^#]*TCP_STRONG_ISS=" /etc/default/inetinit`
  if [ "$TCP_VAL" != "TCP_STRONG_ISS=2" ]; then
    t_echo 0 "       /etc/default/inetinit TCP_STRONG_ISS value improperly set - FAILS CHECK"
    t_echo 2 " Saving /etc/default/inetinit to /etc/default/inetinit.ORIG.$DATE"
    cp -p /etc/default/inetinit /etc/default/inetinit.ORIG.${DATE}
	if [ $? -ne 0 ]; then
           t_echo 1 "     Could not backup /etc/default/inetinit - ERROR"
           exit 1
	else
	t_echo 2     " Changing TCP sequence default "
	ed /etc/default/inetinit <<- EDEND
	g/^TCP_STRONG_ISS/s/TCP_STRONG_ISS=.*/TCP_STRONG_ISS=2/
	.
        w
	q
	EDEND
           t_echo 2 " /etc/default/inetinit changed ... "
        fi

  else
     t_echo 1 "  /etc/default/inetinit TCP_STRONG_ISS value properly set -  PASSES CHECK" 

  fi

else
     t_echo 1 "  ERROR - /etc/default/inetinit file not found." 

fi

}

Check() {

if [ -f /etc/default/inetinit ]; then
  TCP_VAL=`grep -i "^[^#]*TCP_STRONG_ISS=" /etc/default/inetinit`

  if [ "$TCP_VAL" != "TCP_STRONG_ISS=2" ]; then
    t_echo 0 "       /etc/default/inetinit TCP_STRONG_ISS value improperly set - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (tcp-sequence.sh -f) Change the TCP initial sequence number"   
        t_echo 3 "generation parameters to use RFC 1948 sequence number generation, unique-per-"  
        t_echo 3 "connection-ID. Titan modified /etc/default/inetinit TO: TCP_STRONG_ISS=2 " 
        t_echo 3 " "
        t_echo 3 " "
        t_echo 3 "======================================================================== "


  else
     t_echo 1 "  /etc/default/inetinit TCP_STRONG_ISS value properly set -  PASSES CHECK" 

  fi

else
     t_echo 1 "  ERROR - /etc/default/inetinit file not found." 

fi

}

action=$1

   case ${action} in
	-[Ii]*)
	Intro
	;;
	-[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $0 -[ivf] (I)ntro/(V)erify/(F)ix"
	exit 1;;
	esac

