:
# ftpusers.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0 BETA6 Aug 31 11:39:44 PDT 2002 bpowell - sol9 uses /etc/ftpd.users
# so added in a link

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/ftpusers'
OS=`uname -r`
HOST=`uname -n`

. misc_functions.sh

case $OS in
  5*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 60000) {print $1}' /etc/passwd`
  ;;
  4*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 65000) {print $1}' /etc/passwd`
  ;;
 *)
   t_echo 1 "       No valid OS for echo"
 exit 1
;;
esac

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {

cat << EOF

 $MYNAME - This program looks for /etc/ftpusers and if not found creates it.
 If it is found it saves the origional then adds all users with UID
 less than 100 and greater than 60000 and sets the mode on the file.

EOF

}

#
# Default ftpusers list for most Unix variants
#
DEFFTPUSERS="root daemon sys bin adm lp smtp uucp nuucp listen nobody noaccess news ingres audit admin sync nobody4"

Fix() {

        if [ -f /etc/ftpusers ]
        then
        t_echo 2 " /etc/ftpusers already exists; saving a copy "
        cp -p /etc/ftpusers /etc/ftpusers.ORIG.$DATE
		if [ $? -ne 0 ]
       		then
                 t_echo 1 " "
                 t_echo 1 "       ERROR - Could not rename /etc/ftpusers; exiting"
			exit 1
		fi
	fi

 
# if there is a file /etc/ftpusers append it
 
if [  -f /etc/ftpusers ]
then
	/bin/touch /etc/ftpusers
	for USER in $DEFFTPUSERS
	 do
	   grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>/etc/ftpusers
	   else
              t_echo 1 " $USER in /etc/ftpusers - PASSES CHECK"
	   fi
	 done

	t_echo 2 " Checking your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	   grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>/etc/ftpusers
	   else
              t_echo 1 "        $USER in /etc/ftpusers - PASSES CHECK"
	   fi
	 done
	 if test "X$ftpx" != "X" ; then
	    t_echo 2 " Added users to /etc/ftpusers."
	 fi

fi


# if there isn't a file ftpuser, create it
if [  ! -f /etc/ftpusers ]
then
 t_echo 1 " Creating /etc/ftpusers disallowing ftp to the following users:"
 t_echo 1 $DEFFTPUSERS
 t_echo 1 " "

	/bin/touch /etc/ftpusers
 t_echo 2 " Installing default ftpusers names..."
	for USER in $DEFFTPUSERS
	 do
 echo $USER >>/etc/ftpusers
	done

 t_echo 2 " Installing your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	grep "^$USER" /etc/ftpusers >/dev/null 2>&-
	if [ $? -ne 0 ]; then
 echo $USER >>/etc/ftpusers
	else
 t_echo 1 "       $USER in /etc/ftpusers - PASSES CHECK"
	fi
	done

fi

# chmod it when done
/bin/chmod 644 /etc/ftpusers

# and link to the ftpdusers file for solaris 9
ln /etc/ftpusers /etc/ftpdusers

} # End Fix


Check() {

t_echo 2 " Checking /etc/ftpusers file for default matches...."
   for USER in $DEFFTPUSERS
    do
    grep "^$USER" /etc/ftpusers >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in /etc/ftpusers - FAILS CHECK" 
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: ftpusers.sh -f Set up the ftpd to disallow ftp by"
        t_echo 3 "system users. Root, smtp, audit, admin, sync, ftp, nsysuser, and all pseudo-root"
        t_echo 3 "users should be added to /etc/ftpusers to restrict them from overwriting system"
        t_echo 3 "files via ftp. "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

     else
     t_echo 1 "        $USER in /etc/ftpusers - PASSES CHECK"
     fi
    done

t_echo 2 " "
t_echo 2 " Checking /etc/ftpusers file for local matches...."
   for USER in $LOCALFTPUSERS
    do
    grep "^$USER" /etc/ftpusers >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in /etc/ftpusers - FAILS CHECK"
     else
     t_echo 1 "        $USER in /etc/ftpusers - PASSES CHECK"
     fi
    done
t_echo 2 " "
t_echo 2 " Checking /etc/ftpdusers file for local matches...."
   for USER in $LOCALFTPUSERS
    do
    grep "^$USER" /etc/ftpdusers >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in /etc/ftpdusers - FAILS CHECK"
     else
     t_echo 1 "        $USER in /etc/ftpdusers - PASSES CHECK"
     fi
    done

}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
	if [ -f /etc/ftpusers ]; then
           t_echo 2 "          The /etc/ftpusers file exists..."
           t_echo 2 "          Your default ftpusers names: "
           t_echo 2 " "
           t_echo 2 $DEFFTPUSERS
           t_echo 2 " "
           t_echo 2 "       Your local ftpusers names: "
           t_echo 2 " "
           t_echo 2 $LOCALFTPUSERS
           t_echo 2 " "
           Check
	else
           t_echo 0 "       No /etc/ftpusers file in place - FAILS CHECK"
           t_echo 2 "       Should contain at least: "
           t_echo 2 " "
 	for USER in $DEFFTPUSERS
    	   do
              t_echo 2 " $USER"
 	done
        t_echo 2 " "
 	exit 1
	fi
        ;;
        *)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

